@@ -35,7 +35,7 @@ stop(_Pid) ->
 
 erab_fsm_info(Pid, Key) ->
     Info = erab_fsm:fetch_info(Pid),
-    proplists:get_value(Key, Info).
+    maps:get(Key, Info).
 
 
 %% ------------------------------------------------------------------
